@@ -31,26 +31,51 @@ def get_db_engine():
     return _settings["ENGINE"].split(".")[-1]
 
 
-class CmdResult(object):
+class CmdResult:
     def __init__(self, status_code, std_out, std_err):
         self.status_code = status_code
         self.std_out = std_out
         self.std_err = std_err
 
 
-def run_cmd(*args):
-    r = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+def run_cmd(*args, env=None):
+    r = subprocess.Popen(
+        args,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+        env={**os.environ, **(env or {})},
+    )
     stdoutdata, stderrdata = r.communicate()
     ret = r.wait()
     return CmdResult(ret, stdoutdata, stderrdata)
 
 
-def run_mysql(*args):
-    user = _settings.get("USER", None)
+def run_psql(*args):
+    env = {}
+    user = _settings.get("USER")
     if user:  # pragma: no branch
-        args = ("-u", user) + tuple(args)
-    args = ("mysql",) + tuple(args)
-    return run_cmd(*args)
+        args = ("-U", user, *args)
+    password = _settings.get("PASSWORD")
+    if password:  # pragma: no branch
+        env["PGPASSWORD"] = password
+    host = _settings.get("HOST")
+    if host:  # pragma: no branch
+        args = ("-h", host, *args)
+    return run_cmd("psql", *args, env=env)
+
+
+def run_mysql(*args):
+    user = _settings.get("USER")
+    if user:  # pragma: no branch
+        args = ("-u", user, *args)
+    password = _settings.get("PASSWORD")
+    if password:  # pragma: no branch
+        # Note: "-ppassword" must be a single argument.
+        args = ("-p" + password, *args)
+    host = _settings.get("HOST")
+    if host:  # pragma: no branch
+        args = ("-h", host, *args)
+    return run_cmd("mysql", *args)
 
 
 def skip_if_sqlite_in_memory():
@@ -64,7 +89,7 @@ def skip_if_sqlite_in_memory():
 def _get_db_name(db_suffix=None):
     name = TEST_DB_NAME
     if db_suffix:
-        name = "%s_%s" % (name, db_suffix)
+        name = "{}_{}".format(name, db_suffix)
     return name
 
 
@@ -72,8 +97,8 @@ def drop_database(db_suffix=None):
     name = _get_db_name(db_suffix)
     db_engine = get_db_engine()
 
-    if db_engine == "postgresql_psycopg2":
-        r = run_cmd("psql", "postgres", "-c", "DROP DATABASE %s" % name)
+    if db_engine == "postgresql":
+        r = run_psql("postgres", "-c", "DROP DATABASE %s" % name)
         assert "DROP DATABASE" in force_str(
             r.std_out
         ) or "does not exist" in force_str(r.std_err)
@@ -94,8 +119,8 @@ def db_exists(db_suffix=None):
     name = _get_db_name(db_suffix)
     db_engine = get_db_engine()
 
-    if db_engine == "postgresql_psycopg2":
-        r = run_cmd("psql", name, "-c", "SELECT 1")
+    if db_engine == "postgresql":
+        r = run_psql(name, "-c", "SELECT 1")
         return r.status_code == 0
 
     if db_engine == "mysql":
@@ -111,8 +136,8 @@ def db_exists(db_suffix=None):
 def mark_database():
     db_engine = get_db_engine()
 
-    if db_engine == "postgresql_psycopg2":
-        r = run_cmd("psql", TEST_DB_NAME, "-c", "CREATE TABLE mark_table();")
+    if db_engine == "postgresql":
+        r = run_psql(TEST_DB_NAME, "-c", "CREATE TABLE mark_table();")
         assert r.status_code == 0
         return
 
@@ -136,8 +161,8 @@ def mark_database():
 def mark_exists():
     db_engine = get_db_engine()
 
-    if db_engine == "postgresql_psycopg2":
-        r = run_cmd("psql", TEST_DB_NAME, "-c", "SELECT 1 FROM mark_table")
+    if db_engine == "postgresql":
+        r = run_psql(TEST_DB_NAME, "-c", "SELECT 1 FROM mark_table")
 
         # When something pops out on std_out, we are good
         return bool(r.std_out)
