@@ -1,7 +1,3 @@
-import os
-
-import django
-
 ROOT_URLCONF = "pytest_django_test.urls"
 INSTALLED_APPS = [
     "django.contrib.auth",
@@ -14,10 +10,6 @@ INSTALLED_APPS = [
 STATIC_URL = "/static/"
 SECRET_KEY = "foobar"
 
-# Used to construct unique test database names to allow detox to run multiple
-# versions at the same time
-db_suffix = "_%s" % os.getuid()
-
 MIDDLEWARE = [
     "django.contrib.sessions.middleware.SessionMiddleware",
     "django.middleware.common.CommonMiddleware",
@@ -26,9 +18,6 @@ MIDDLEWARE = [
     "django.contrib.messages.middleware.MessageMiddleware",
 ]
 
-if django.VERSION < (1, 10):
-    MIDDLEWARE_CLASSES = MIDDLEWARE
-
 
 TEMPLATES = [
     {
